@@ -3,8 +3,7 @@
 #' Please see the package vignettes for usage instructions. For a quick start,
 #' check out the examples for [`geom_density_ridges()`].
 #'
-#' @name ggridges
-#' @docType package
 #' @import ggplot2
-NULL
+#' @keywords internal
+"_PACKAGE"
 
